#[repr(i32)]pub enum TextMeasurementOperation {
Show 19 variants
Measure = 0,
ComputedLength = 1,
BBoxX = 2,
BBoxXWithAsciiOverhang = 3,
TitleBBoxX = 4,
SimpleBBoxWidth = 5,
RawBBoxWidth = 6,
TspanBBoxWidth = 7,
TspanBBoxHeight = 8,
WrapProbeBBoxWidth = 9,
SimpleBBoxHeight = 10,
Wrapped = 11,
WrappedWithRawWidth = 12,
BoundingClientRectWidth = 13,
CreateTextBBoxYOffset = 14,
MermaidCalculateTextDimensions = 15,
CanvasMeasureTextWidth = 16,
CreateTextMiddleBBoxYOffset = 17,
RawBBoxHeight = 18,
}Expand description
The exact TextMeasurer operation performed through a phase facade and its required host
result shape. Both types are generated from the independently versioned host
text-measurement protocol shared by every binding.
The exact TextMeasurer operation performed through a phase facade and its required host
result shape. Both types are generated from the independently versioned host
text-measurement protocol shared by every binding.
The exact TextMeasurer operation performed through a phase facade and its required host
result shape. Both types are generated from the independently versioned host
text-measurement protocol shared by every binding.
Variants
Measure = 0
ComputedLength = 1
BBoxX = 2
BBoxXWithAsciiOverhang = 3
TitleBBoxX = 4
SimpleBBoxWidth = 5
RawBBoxWidth = 6
TspanBBoxWidth = 7
TspanBBoxHeight = 8
WrapProbeBBoxWidth = 9
SimpleBBoxHeight = 10
Wrapped = 11
WrappedWithRawWidth = 12
BoundingClientRectWidth = 13
CreateTextBBoxYOffset = 14
MermaidCalculateTextDimensions = 15
CanvasMeasureTextWidth = 16
CreateTextMiddleBBoxYOffset = 17
RawBBoxHeight = 18
Implementations
Sourceimpl TextMeasurementOperation
impl TextMeasurementOperation
pub const ALL: [Self; 19]
pub const fn external_code(self) -> i32
pub const fn external_name(self) -> &'static str
pub const fn required_result_kind(self) -> TextMeasurementResultKind
pub const fn accepts_signed_length(self) -> bool
pub const fn from_external_code(code: i32) -> Option<Self>
pub fn from_external_name(name: &str) -> Option<Self>