pub struct RenderSession { /* private fields */ }Expand description
Opaque operation session. Family code receives only the narrow projection it needs.
Implementations
Sourceimpl RenderSession
impl RenderSession
pub fn text_measurer( &self, default_phase: TextMeasurementPhase, ) -> RoutedTextMeasurer<'_>
pub fn text_measurement_route( &self, phase: TextMeasurementPhase, ) -> TextMeasurementRoute
pub fn text_measurement_report(&self) -> TextMeasurementReport
pub fn operation_context(&self) -> &OperationContext
pub fn operation_timing(&self) -> Option<OperationTiming>
pub const fn unix_millis(&self) -> i64
pub const fn local_date(&self) -> CivilDate
pub fn local_time_zone(&self) -> &LocalTimeZone
pub fn render_seed(&self) -> NonZeroU64
pub const fn resource_policy(&self) -> RenderResourcePolicy
pub fn math_renderer(&self) -> Option<&(dyn MathRenderer + Send + Sync)>
pub fn icon_registry(&self) -> Option<&IconRegistry>
Sourcepub fn report(&self) -> RenderSessionReport
pub fn report(&self) -> RenderSessionReport
Freezes the observable policy and provenance accumulated so far.